pub enum CreateSamplingRuleError {
InvalidRequest(String),
RuleLimitExceeded(String),
Throttled(String),
}Expand description
Errors returned by CreateSamplingRule
Variants
InvalidRequest(String)
The request is missing required parameters or has invalid parameters.
RuleLimitExceeded(String)
You have reached the maximum number of sampling rules.
Throttled(String)
The request exceeds the maximum number of requests per second.
Implementations
Sourceimpl CreateSamplingRuleError
impl CreateSamplingRuleError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateSamplingRuleError>